@@ -1,11 +1,13 @@
 use once_cell::sync::Lazy;
 use std::{env, process::Command};
-use swc_common::{sync::Lrc, SourceMap, SyntaxContext};
-use swc_ecma_ast::{Ident, Module, StrKind};
+use swc_common::{sync::Lrc, SourceMap, SyntaxContext, DUMMY_SP};
+use swc_ecma_ast::*;
 use swc_ecma_codegen::{text_writer::JsWriter, Emitter};
 use swc_ecma_transforms::{fixer, hygiene};
 use swc_ecma_utils::{drop_span, DropSpan};
-use swc_ecma_visit::{noop_visit_mut_type, FoldWith, VisitMut, VisitMutWith};
+use swc_ecma_visit::{
+    noop_visit_mut_type, noop_visit_type, FoldWith, Node, Visit, VisitMut, VisitMutWith, VisitWith,
+};
 
 pub(crate) struct Debugger;
 
@@ -62,6 +64,10 @@ pub(crate) fn invoke(module: &Module) {
     static ENABLED: Lazy<bool> =
         Lazy::new(|| cfg!(feature = "debug") && env::var("SWC_RUN").unwrap_or_default() == "1");
 
+    if cfg!(debug_assertions) {
+        module.visit_with(&Invalid { span: DUMMY_SP }, &mut AssertValid);
+    }
+
     if !*ENABLED {
         return;
     }
@@ -108,3 +114,23 @@ pub(crate) fn invoke(module: &Module) {
         String::from_utf8_lossy(&output.stdout)
     )
 }
+
+pub(crate) struct AssertValid;
+
+impl Visit for AssertValid {
+    noop_visit_type!();
+
+    fn visit_invalid(&mut self, _: &Invalid, _: &dyn Node) {
+        panic!("[SWC_RUN] Invalid node found");
+    }
+
+    fn visit_setter_prop(&mut self, p: &SetterProp, _: &dyn Node) {
+        p.body.visit_with(p, self);
+    }
+
+    fn visit_tpl(&mut self, l: &Tpl, _: &dyn Node) {
+        l.visit_children_with(self);
+
+        assert_eq!(l.exprs.len() + 1, l.quasis.len());
+    }
+}
